#ifndef COLUMBUSDIALOGTOOLS_H
#define COLUMBUSDIALOGTOOLS_H

#include "widgets/ColumbusDialog.h"

#include <QMaemo5ValueButton>

class ColumbusDialogTools : public ColumbusDialog
{
    Q_OBJECT

public:
    explicit ColumbusDialogTools(QWidget *parent = 0);

    void setController(ColumbusController *controller);

private:
    void                setupUi         ();
};

#endif // COLUMBUSDIALOGTOOLS_H
